function [trainMatSim, testMatSim] = ...
  multiCentroid_computeSimilarityMatrices(trainMat, trainClass, testMat, simFunction)
% Compute pairwise training set similarities and similarities of test
% set to training set.

% Written by Luca Cazzanti, engineer
% Applied Physics Laboratory, University of Washington, Dec 2006.

[nTrain, nFeatures] = size(trainMat); %#ok
[nTest, nFeatures] = size(testMat); %#ok

trainMatSim = zeros(nTrain,nTrain);
testMatSim = zeros(nTrain, nTest);
switch simFunction
  case 'Hamming'
    for iTrain = 1:nTrain
      trainMatSim(:,iTrain) = computeHammingSimilarity(trainMat(iTrain,:), ...
        trainMat);
    end
    for iTest = 1:nTest
      testMatSim(:,iTest) = computeHammingSimilarity(testMat(iTest,:), ...
        trainMat);
    end
  case 'vdm'
    trainMatSim = zeros(nTrain,nTrain);
    [vdmTables, possibleFeatureVals] = computeVdmTables(trainMat, trainClass);
    for iTrain = 1:nTrain
      trainMatSim(:,iTrain) = computeVdmSimilarity(trainMat(iTrain,:), ...
        trainMat, vdmTables, possibleFeatureVals);
    end
    for iTest = 1:nTest
      testMatSim(:,iTest) = computeVdmSimilarity(testMat(iTest,:), ...
        trainMat, vdmTables, possibleFeatureVals);
    end
  case 'resEnt'
    Hmax = computeSetEntropy(trainMat);
    for iTrain = 1:nTrain
      for jTrain = 1:nTrain
        [notUsed, trainMatSim(iTrain,jTrain)] = computeResidualEntropySimilarity( ...
          trainMat(iTrain,:), trainMat(jTrain,:), trainMat, Hmax); %#ok
      end %for jTrain
    end % for iTrain
    for iTrain = 1:nTrain
      for iTest = 1:nTest
        [notUsed, testMatSim(iTrain,iTest)] = computeResidualEntropySimilarity( ...
          testMat(iTest,:), trainMat(iTrain,:), [trainMat;testMat(iTest,:)]); %#ok
      end %for iTest
    end % for iTrain
  otherwise
    error('Unsupported similarity')
end % switch

testMatSim = testMatSim.';
return
