// Header file for computing the SDA parameters. Uses the Brent's method for function
// minimization. This implementation of brent() is due to the authors below and is covered
// by the license below:
// GNU General Public License Agreement
// Copyright (C) 2004-2007 CodeCogs, Zyba Ltd, Broadwood, Holford, TA5 1DU, England.
//
// This program is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by CodeCogs. 
// You must retain a copy of this licence in all copies. 
//
// This program is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
// PARTICULAR PURPOSE. See the GNU General Public License for more details.
// ---------------------------------------------------------------------------------

// All other functions were originally written by Ingrid Liu and Peter Sadowski,
// Information Design Lab, University of Washington, Summer/Fall 2009. Adapted by Luca
// Cazzanti, Applied Physics Lab, Univ. Washington to be use as a mex file, Fall 2009.
// First complete version: Dec 1, 2009. 
#ifndef IDL_BRENTEXP_H
#define IDL_BRENTEXP_H


#include <algorithm>
#include <vector>

#include "RealMatrix.h"

namespace idl
{

  double meanConstraintFxn(double lambda, const RealMatrix &domainVector, double classMean);

  bool getLambdaGamma(const RealMatrix &domainVector, double classMean, double &lambda, double &gamma);

  double brent (double (*f)(double,const RealMatrix&,double), const RealMatrix &domainVector, double classMean,
		double a, double b, double c, double eps, int maxit);

}

#endif
