function modelParams = computeSdaModels( simMat, classLabels, ...
  centroidType, varargin)
%computeSdaModels -  compute SDA model parameters.
% This function is a wrapper around computeMaxEntModels() and 
% additionally handles the case of only one class being represented in the
% training set. This function works for multi-class classification.
% 
% USAGE
% modelParams = computeSdaModels( simMat, classLabels, centroidType, ...
%     simDomain)
%
% See computeMaxEntModels() for specifics on the input and output
% arguments. See also initSdaModels, classifySda.

% Written by Luca Cazzanti, engineer
% Applied Physics Laboratory, University of Washington, Jan 2007.
%$Id:$
%$DateTime:$
%$Author:$

uniqueClassLabels = unique(classLabels);
nClasses = length(uniqueClassLabels);
if nClasses == 1 % If only one class, return the trivial class model
  % Tnitialize model parameters struct with empty fields
  modelParams = initSdaModels;
  
  modelParams.isTrivial = true;
  modelParams.classCounts = size(simMat,1);
  modelParams.classPriors = 1; % only two classes for now
  modelParams.classLabels = uniqueClassLabels;
  % All other fields are empty 
  
else % two classes, compute the max ent models
  
  modelParams = computeMaxEntModels(simMat, classLabels, ...
    centroidType, varargin{:});
end

return